@@ -1,4 +1,4 @@
-from pysimmods.model.inputs import ModelInputs
+from ...model.inputs import ModelInputs
 
 
 class BatteryInputs(ModelInputs):
