@@ -39,10 +39,10 @@ def biogas_presets(pn_max_kw, **kwargs):
     method_params = f"params_{possible_p[0][1]}g_{possible_p[0][0]}kw"
     method_inits = f"inits_{possible_p[0][1]}g_{possible_p[0][0]}kw"
 
-    return (
-        getattr(thismodule, method_params)(),
-        getattr(thismodule, method_inits)(),
-    )
+    params = getattr(thismodule, method_params)()
+    params["sign_convention"] = "active"
+
+    return params, getattr(thismodule, method_inits)()
 
 
 def params_1g_40kw():
@@ -742,9 +742,30 @@ def params_3g_1500kw():
         "has_heat_storage": False,
         "num_chps": 3,
         "chp0": {
-            "pn_stages_kw": [125.0, 250.0, 375.0, 500.0, 625.0, 750.0],
-            "eta_stages_percent": [26.1, 27.0, 27.3, 28.0, 27.7, 27.5],
-            "eta_th_stages_percent": [50.0, 50.2, 50.5, 50.9, 51.0, 52.1],
+            "pn_stages_kw": [
+                125.0,
+                250.0,
+                375.0,
+                500.0,
+                625.0,
+                750.0,
+            ],
+            "eta_stages_percent": [
+                26.1,
+                27.0,
+                27.3,
+                28.0,
+                27.7,
+                27.5,
+            ],
+            "eta_th_stages_percent": [
+                50.0,
+                50.2,
+                50.5,
+                50.9,
+                51.0,
+                52.1,
+            ],
             "restarts_per_day": 0,
             "active_min_s": 3 * 3_600,
             "active_max_s_per_day": 0,
