@@ -1,5 +1,12 @@
+from typing import List
 from pysimmods.model.config import ModelConfig
 
+DEFAULT_SCHEDULE: List[float] = (
+    [50, 50, 50, 50, 50, 100, 100, 100]
+    + [100, 50, 50, 50, 100, 100, 50, 50]
+    + [50, 100, 100, 100, 100, 50, 50, 50]
+)
+
 
 class DieselGenConfig(ModelConfig):
     def __init__(self, params):
@@ -10,32 +17,10 @@ class DieselGenConfig(ModelConfig):
         self.q_max_kvar = params["q_max_kvar"]
         self.q_min_kvar = params["q_min_kvar"]
 
-        self._default_schedule = [
-            50,
-            50,
-            50,
-            50,
-            50,
-            100,
-            100,
-            100,
-            100,
-            50,
-            50,
-            50,
-            100,
-            100,
-            50,
-            50,
-            50,
-            100,
-            100,
-            100,
-            100,
-            50,
-            50,
-            50,
+        self.default_p_schedule: List[float] = [
+            self.p_min_kw + dv * self.p_max_kw / 100 for dv in DEFAULT_SCHEDULE
         ]
+        self.default_q_schedule: List[float] = [0.0] * 24
 
     # @property
     # def p_max_kw(self):
