@@ -9,6 +9,8 @@ class PVSystemInputs(ModelInputs):
     ----------
     cos_phi_set : float
         See :attr:`~.InverterInputs.cos_phi_set`.
+    inverter_inductive:: bool
+        See _attr:`~.InverterInputs.inverter_inductive`.
     bh_w_per_m2 : float
         See :attr:`~.PVInputs.bh_w_per_m2`.
     dh_w_per_m2 : float
@@ -18,12 +20,14 @@ class PVSystemInputs(ModelInputs):
     t_air_deg_celsius : float
         See :attr:`~.PVInputs.t_air_deg_celsius`.
 
+
     """
 
     def __init__(self):
         super().__init__()
 
         self.cos_phi_set = None
+        self.inverter_inductive = None
         self.bh_w_per_m2 = None
         self.dh_w_per_m2 = None
         self.s_module_w_per_m2 = None
