@@ -3,7 +3,7 @@ import logging
 
 import pandas as pd
 from midas.util.upgrade_module import UpgradeModule
-from pysimmods.buffer.batterysim.presets import battery_presets
+from pysimmods.buffer.batterysim.presets import battery_preset
 from pysimmods.consumer.hvacsim.presets import hvac_preset
 from pysimmods.generator.biogassim.presets import biogas_presets
 from pysimmods.generator.chplpgsystemsim.presets import chp_presets
@@ -81,7 +81,7 @@ class PysimmodsModule(UpgradeModule):
 
         module_params.setdefault("start_date", self.scenario.base.start_date)
         module_params.setdefault("cos_phi", self.scenario.base.cos_phi)
-        module_params.setdefault("q_control", "p_set")
+        module_params.setdefault("q_control", "prioritize_p")
         module_params.setdefault("inverter_mode", "inductive")
         module_params.setdefault(
             "forecast_horizon_hours",
@@ -100,7 +100,7 @@ class PysimmodsModule(UpgradeModule):
         module_params.setdefault("num_schedules", 10)
         module_params.setdefault("unit", "mw")
         module_params.setdefault("use_decimal_percent", False)
-        module_params.setdefault("priorize_setpoint", False)
+        module_params.setdefault("prioritize_setpoint", False)
         module_params.setdefault(
             "provide_forecasts", module_params["provide_flexibilities"]
         )
@@ -146,7 +146,7 @@ class PysimmodsModule(UpgradeModule):
             module_params["use_decimal_percent"],
         )
         self.sim_params.setdefault(
-            "priorize_setpoint", module_params["priorize_setpoint"]
+            "prioritize_setpoint", module_params["prioritize_setpoint"]
         )
         self.sim_params.setdefault(
             "provide_forecasts",
@@ -209,14 +209,33 @@ class PysimmodsModule(UpgradeModule):
                     params = self.generate_model_params(
                         model_key, model, p_peak_mw
                     )
+                    sn_mva = params["params"].get("sn_mva", p_peak_mw)
                     full_id = self.start_model(model_key, info[0], params)
+
                     eid_mapping[full_id] = {
                         "p_mw": p_peak_mw,
                         "bus": bus,
                         "type": info[1],
-                        "sn_mva": params.get("sn_mva", p_peak_mw),
+                        "sn_mva": sn_mva,
                     }
-
+                    self.actuators.append(
+                        {
+                            "actuator_id": f"{full_id}.p_set_mw",
+                            "action_space": (
+                                f"Box(low=0, high={p_peak_mw}, shape=(1,),"
+                                "dtype=np.float32)"
+                            ),
+                        }
+                    )
+                    self.actuators.append(
+                        {
+                            "actuator_id": f"{full_id}.q_set_mvar",
+                            "action_space": (
+                                f"Box(low={-sn_mva}, high={sn_mva}, shape=(1,),"
+                                "dtype=np.float32)"
+                            ),
+                        }
+                    )
                     self.actuators.append(
                         {
                             "actuator_id": (f"{full_id}.set_percent"),
@@ -231,7 +250,7 @@ class PysimmodsModule(UpgradeModule):
                             {
                                 "sensor_id": (f"{full_id}.{attr}"),
                                 "observation_space": (
-                                    "Box(low=0, high=100, shape=(1,), "
+                                    "Box(low=-10000, high=10000, shape=(1,), "
                                     "dtype=np.float32)"
                                 ),
                             }
@@ -355,7 +374,7 @@ class PysimmodsModule(UpgradeModule):
                         self, model.lower(), bus, model_ctrs[model]
                     )
 
-                    fc_attrs = info[3] + ["target"]
+                    fc_attrs = info[3]
                     try:
                         self.connect_entities(model_key, db_key, fc_attrs)
                     except ScenarioError:
@@ -535,7 +554,7 @@ def get_presets(model, p_peak_mw, **kwargs):
     elif model == "CHP":
         return chp_presets(p_kw=p_peak_mw * 1e3, **kwargs)
     elif model == "BAT":
-        return battery_presets(pn_max_kw=p_peak_mw * 1e3)
+        return battery_preset(pn_max_kw=p_peak_mw * 1e3)
     elif model == "DIESEL":
         return diesel_presets(p_max_kw=p_peak_mw * 1e3)
     elif model == "Biogas":
