@@ -1,5 +1,6 @@
 """This module contains the :class:`ForecastModel`."""
-from datetime import timedelta
+from datetime import datetime, timedelta
+from typing import Optional
 
 import numpy as np
 import pandas as pd
@@ -16,17 +17,19 @@ from . import LOG
 class ForecastModel(ScheduleModel):
     """The forecast model for all pysimmods.
 
+    This class extends the schedule model and allows to forecast the
+    next steps.
+
     Parameters
     ----------
     model: :class:`.Model`
-        An instance of a subclass of the base model class (e.g.,
-        :class:`.Battery` model).
-    start_date: str or datetime
-        An ISO datetime string or a datetime object defining the start
-        date.
-    step_size: int, optional
-        The step size of the model in seconds. Will be used as fallback
-        if no step size is provided to the model. Defaults to 900.
+        The model that should be wrapped by the schedule model.
+    unit: str, optional
+        The unit to be used by the schedule. Default is `kw` for kilo
+        watt. Other options are `w` and `mw`.
+    prioritize_setpoint: bool, optional
+        If set to True, this model will prefer setpoints rather than
+        schedule values if setpoints are present. Default is False.
     forecast_horizon_hours: float, optional
         The number of hours the model should create a forecast for.
         If the model needs a weather forecast, this weather forecast
@@ -55,13 +58,15 @@ class ForecastModel(ScheduleModel):
         self,
         model: Model,
         unit="kw",
-        priorize_setpoint: bool = False,
-        forecast_horizon_hours=1,
+        prioritize_setpoint: bool = False,
+        step_size: Optional[int] = None,
+        now_dt: Optional[datetime] = None,
+        forecast_horizon_hours: float = 1,
     ):
-        super().__init__(model, unit, priorize_setpoint)
+        super().__init__(model, unit, prioritize_setpoint, step_size, now_dt)
 
-        self._forecasts = None
-        self._fch_hours = forecast_horizon_hours
+        self._forecasts: Optional[pd.DataFrame] = None
+        self._horizon_hours = forecast_horizon_hours
 
     def step(self):
         """Perform a simulation step of the underlying model.
@@ -96,6 +101,7 @@ class ForecastModel(ScheduleModel):
             ]
 
     def _check_schedule(self):
+        self.schedule.horizon_hours = self._horizon_hours
 
         if self.schedule.reschedule_required():
             self._create_default_schedule()
@@ -105,7 +111,7 @@ class ForecastModel(ScheduleModel):
         state_backup = self._model.get_state()
 
         now = self._now_dt + timedelta(seconds=self._step_size)
-        periods = int(self._fch_hours * 3_600 / self._step_size)
+        periods = int(self._horizon_hours * 3_600 / self._step_size)
 
         for _ in range(periods):
             self._prepare_step(now)
@@ -115,20 +121,25 @@ class ForecastModel(ScheduleModel):
 
         self._model.set_state(state_backup)
 
-    def _prepare_step(self, now):
+    def _prepare_step(self, now: datetime):
         if not self.schedule.has_index(now):
-            self.schedule.update_row(now, np.nan, np.nan, np.nan)
+            self.schedule.update_row(now, np.nan, np.nan, np.nan, np.nan)
 
-        default_setpoint = (
-            self._model.get_default_setpoint(now.hour) * self._percent_factor
-        )
+        default_p = self._model.get_default_p_set(now.hour)
+        default_q = self._model.get_default_q_set(now.hour)
 
-        if np.isnan(self.schedule.get(now, "target")):
-            self.schedule.update_entry(now, "target", default_setpoint)
+        if self.schedule.get(now, self._psetname) is None:
+            self.schedule.update_entry(now, self._psetname, default_p)
+        if self.schedule.get(now, self._qsetname) is None:
+            self.schedule.update_entry(now, self._qsetname, default_q)
 
     def _perform_step(self, now):
         try:
-            self._calculate_step(now, self.schedule.get(now, "target"))
+            self._calculate_step(
+                now,
+                self.schedule.get(now, self._psetname),
+                self.schedule.get(now, self._qsetname),
+            )
 
             self.schedule.update_entry(
                 now,
@@ -148,10 +159,13 @@ class ForecastModel(ScheduleModel):
                 now,
                 self._model,
             )
-            self.schedule.update_row(now, np.nan, np.nan, np.nan)
+            self.schedule.update_row(now, np.nan, np.nan, np.nan, np.nan)
 
-    def _calculate_step(self, index, set_percent):
-        self._model.set_percent(set_percent / self._percent_factor)
+    def _calculate_step(self, index, p_set, q_set):
+        if p_set is not None and ~np.isnan(p_set):
+            self._model.set_p_kw(p_set * self._unit_factor)
+        if q_set is not None and ~np.isnan(q_set):
+            self._model.set_q_kvar(q_set * self._unit_factor)
 
         if self._forecasts is not None:
             for col in self._forecasts.columns:
